Class: UsageMeter::EventType

Inherits:
ApplicationRecord show all
Defined in:
app/models/usage_meter/event_type.rb

Overview

EventType allows strict categorization of events

Events of the same category and Customer will tally together for the usage of that type Events must have a type, and types will be enforced with a foreign key ref.

Key must be unique, to allow lookup

Constant Summary collapse

KEY_FORMAT =
/\A[a-z0-9\-_]+\z/

Class Method Summary collapse

Class Method Details

.key_formatObject



14
15
16
# File 'app/models/usage_meter/event_type.rb', line 14

def self.key_format
  KEY_FORMAT
end